SystemOrganization addCategory: #ConfigurationOfOmni!

Object subclass: #ConfigurationOfOmni
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfOmni'!

!ConfigurationOfOmni class methodsFor: 'development support' stamp: 'StefanMarr 11/9/2011 00:54'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfOmni class methodsFor: 'private' stamp: 'StefanMarr 11/9/2011 00:54'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfOmni class methodsFor: 'private' stamp: 'StefanMarr 11/9/2011 00:54'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfOmni class methodsFor: 'private' stamp: 'StefanMarr 11/9/2011 00:54'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfOmni class methodsFor: 'metacello tool support' stamp: 'StefanMarr 11/9/2011 00:54'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 11/9/2011 00:54'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 11/9/2011 00:54'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 11/9/2011 00:54'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfOmni class methodsFor: 'accessing' stamp: 'StefanMarr 11/9/2011 00:54'!
project

	^self new project! !

!ConfigurationOfOmni class methodsFor: 'transporter' stamp: 'StefanMarr 11/9/2011 00:54'!
saveWithTransporter
	"Will save the package in file-out format using the Transporter infrastructure"
	self transporters
		ifNotNilDo: [:transporters | 
			transporters do: [:t | t saveNoPopup ]].! !

!ConfigurationOfOmni class methodsFor: 'transporter' stamp: 'StefanMarr 12/11/2011 19:18'!
subPackages
	"Specifies the names of all logical subpackages of the Omni package."
	"TODO: have a versioning for this, to better comply with the Metacello approach."
	^ {	'OmniST-Core'.
		'OmniST-Languages'.
		'OmniVM'.
	}! !

!ConfigurationOfOmni class methodsFor: 'transporter' stamp: 'StefanMarr 11/9/2011 00:54'!
transporters
	"Returns the transporters that define how to file out the different packages for versioning with Git."
	Smalltalk globals at: #Transporter ifPresent: [ :tpCls |
		^ self subPackages collect: [:pkg | tpCls forPackage: (PackageInfo named: pkg) ]
	].
	
	" Else "
	^ nil.! !

!ConfigurationOfOmni class methodsFor: 'transporter' stamp: 'StefanMarr 11/9/2011 00:54'!
transportersForFileOutMenu
	^ self transporters! !

!ConfigurationOfOmni class methodsFor: 'development support' stamp: 'StefanMarr 11/9/2011 00:54'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfOmni methodsFor: 'baselines' stamp: 'StefanMarr 1/2/2012 16:23'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		
		"AST-Compiler (RBCompiler)"
		spec package: 'AST-Compiler' with: [
				spec repository: 'http://source.lukas-renggli.ch/helvetia'].
		
		"SMark Benchmarking"
		spec project: 'Benchmarking'
			with:
				[ spec
					className: 'ConfigurationOfBenchmarking';
					file: 'ConfigurationOfBenchmarking';
					repository: 'http://www.squeaksource.com/SMark' ].
		
		spec
			repository: 'http://ss3.gemstone.com/ss/Omni';
			package: 'OmniPrerequisites';

			package: 'OmniST-Core' with: [
				spec 
					requires:   #('AST-Compiler' 'Benchmarking' 'OmniPrerequisites').];

			package: 'OmniST-Languages' with: [
				spec requires: 'OmniST-Core'];

			package: 'OmniVM'
	].
! !

!ConfigurationOfOmni methodsFor: 'symbolic versions' stamp: 'StefanMarr 11/9/2011 00:54'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.1'.
! !

!ConfigurationOfOmni methodsFor: 'accessing' stamp: 'StefanMarr 11/9/2011 00:54'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfOmni methodsFor: 'versions' stamp: 'StefanMarr 11/9/2011 00:54'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'StefanMarr'.
		spec timestamp: '5/14/2011 12:19'.
	].! !
